@@ -501,22 +501,27 @@ class mCalendar:
             end_format = ''
 
           if (start_datetime.date()==end_datetime.date()) or (self.current_view == 0):
-            if (start_format==DAY_VIEW_FORMAT) and (end_format==DAY_VIEW_FORMAT):
+            if (start_format==DAY_VIEW_FORMAT) and (end_format==DAY_VIEW_FORMAT):           
               ds = start_datetime.strftime(start_format)+'\n'+end_datetime.strftime(end_format)
               de = ''
+            elif (start_format==ALLDAY_VIEW_FORMAT):
+              ds = start_datetime.strftime(start_format)
+              de = ''
             else:
               ds = start_datetime.strftime(start_format)+'\n'+end_datetime.strftime(end_format)
-              de = end_datetime.strftime(end_format)   
+              de = end_datetime.strftime(end_format)
+               
+              
             self.event_list.append((start_datetime,(ds,de,description,uuid,d1,d2,fg,bg)))                
           else:
             for d in range( (end_datetime - start_datetime).days+1):
               diff = datetime.timedelta(days=d)
-              if (start_format==DAY_VIEW_FORMAT) and (end_format==DAY_VIEW_FORMAT):
+              if (start_format==DAY_VIEW_FORMAT):
                 ds = (start_datetime + diff).strftime(start_format)+'\n'+end_datetime.strftime(end_format)
                 de = ''
               else:
                 ds = (start_datetime + diff).strftime(start_format)
-                de = end_datetime.strftime(end_format)   
+                de = end_datetime.strftime(end_format)  
 
               if ((self.current_view==1) and (start_datetime.strftime("%W")==((start_datetime+diff).strftime("%W")))) or ((self.current_view==2) and (start_datetime.strftime("%M")==((start_datetime+diff).strftime("%M")))):             
                 self.event_list.append((start_datetime+diff,(ds,de,description,uuid,d1,d2,fg,bg)))
