@@ -84,7 +84,8 @@ class Event:
               self.description = event[2]
               self.lastup = datetime.datetime.strptime(event[7],DB_FORMAT)
               self.googleid = event[6]
-              self.cal_id = event[13]
+              if event[13] != None:
+                self.cal_id = event[13]
               self.frequency = event[8]
               self.repeat_byday = event[9]
               if event[10]!=None:
@@ -113,6 +114,9 @@ class Event:
               d = self.start_datetime - diff
               self.alarm_id = osso.alarmd.add_alarm(time.mktime(d.timetuple()),title=strip_accents(self.description))
               debug(self.alarm_id)
+              
+            if self.cal_id == None:
+              self.cal_id = "default"
 
             debug('cal_id'+str(self.cal_id))
             debug('google_id:'+str(self.googleid))
