@@ -120,7 +120,7 @@ class _Thread(threading.Thread, _IdleObject):
                     local_event.start_datetime = dateFromGoogle(value,1)
                   else:
                     local_event.start_datetime = dateFromGoogle(value,2)
-                    local_event.start_datetime = e.start_datetime.replace(hour=0,minute=0)
+                    local_event.start_datetime = local_event.start_datetime.replace(hour=0,minute=0)
                 elif 'DTEND' in line:
                   value = line.split(':')[1]
                   if 'T' in value:
@@ -412,7 +412,6 @@ class _Thread(threading.Thread, _IdleObject):
           self.emit("progress", 90)
           debug('progress 90')
 
-        
         except (StandardError,gdata.service.Error,gdata.service.RequestError,socket.error) ,e:
           import traceback
           t = str(traceback.print_exc())
